@@ -27,7 +27,10 @@ class ProgressiveResult(TextTestResult):
 
         if self._term.is_a_tty or self._options.with_bar:
             # 1 in case test counting failed and returned 0
-            self.bar = ProgressBar(total_tests or 1, self._term)
+            self.bar = ProgressBar(total_tests or 1,
+                                   self._term,
+                                   config.options.bar_filled_color,
+                                   config.options.bar_empty_color)
         else:
             self.bar = NullProgressBar()
 
@@ -38,7 +41,7 @@ class ProgressiveResult(TextTestResult):
     def startTest(self, test):
         """Update the progress bar."""
         super(ProgressiveResult, self).startTest(test)
-        self.bar.update(test, self.testsRun)
+        self.bar.update(nose_selector(test), self.testsRun)
 
     def _printTraceback(self, test, err):
         """Print a nicely formatted traceback.
@@ -166,7 +169,7 @@ class ProgressiveResult(TextTestResult):
             # being Englishlike:
             ret = '%s %s%s' % (number, type, 's' if number != 1 else '')
             if is_failure and number:
-                ret = self._term.bold + ret + self._term.normal
+                ret = self._term.bold(ret)
             return ret
 
         # Summarize the special cases:
